# mlmc

**M**ulti**l**abel **M**ulti**c**lass

Packaging for experimenting with neural networks and multilabel text classification.


Before installing, make sure the right pytorch package is installed 
for your cuda setup. Download the right version from 
[https://download.pytorch.org/whl/torch_stable.html](https://download.pytorch.org/whl/torch_stable.html)

Install with
```
pip install git+https://git.informatik.uni-leipzig.de/asv-ml/mlmc@v0.1.4
```

## Documentation
For more detailed explanations, see the [Documentation](https://mlmc-docs.readthedocs.io/en/latest/contents.html) on readthedocs.org.